# `datamol.viz`

## Vizualize molecule in 2D or 3D

::: datamol.viz.to_image
::: datamol.viz.conformers

## Specific plotting functions

::: datamol.viz.MolsCircleGrid
::: datamol.viz.circle_grid

## Vizualize 2D molecule with highlighted substructures

::: datamol.viz.lasso_highlight_image
